@@ -1,4 +1,4 @@
-from pythonfmu3.fmi3slave import Fmi3Slave, Fmi3Causality, Real
+from pythonfmu3.fmi3slave import Fmi3Slave, Fmi3Causality, Float64
 
 
 class PythonSlaveWithException(Fmi3Slave):
@@ -8,8 +8,8 @@ class PythonSlaveWithException(Fmi3Slave):
 
         self.realIn = 22.0
         self.realOut = 0.0
-        self.register_variable(Real("realIn", causality=Fmi3Causality.input))
-        self.register_variable(Real("realOut", causality=Fmi3Causality.output))
+        self.register_variable(Float64("realIn", causality=Fmi3Causality.input))
+        self.register_variable(Float64("realOut", causality=Fmi3Causality.output))
 
     def do_step(self, current_time, step_size):
         raise RuntimeError()
